@@ -90,7 +90,7 @@ static gint adjust_argnum(lua_State *L, gint argnum) {
 
 
 /* Pushes an error message onto Lua stack if script passes a wrong arg type */
-static gint fail_arg_type(lua_State *L, const gchar *func, gint argnum, gchar *type)
+static gint fail_arg_type(lua_State *L, const gchar *func, gint argnum, const gchar *type)
 {
 	lua_pushfstring(L, _("Error in module \"%s\" at function %s():\n"
 											" expected type \"%s\" for argument #%d\n"),
@@ -103,7 +103,7 @@ static gint fail_arg_type(lua_State *L, const gchar *func, gint argnum, gchar *t
 
 /*Pushes an error message onto Lua stack if table contains wrong element type*/
 static gint gsdl_fail_elem_type(
-		lua_State *L, const gchar *func, gint argnum, gint idx, gchar *type)
+		lua_State *L, const gchar *func, gint argnum, gint idx, const gchar *type)
 {
 	lua_pushfstring(L, _("Error in module \"%s\" at function %s():\n"
 											" invalid table in argument #%d:\n"
@@ -425,8 +425,8 @@ gint luaopen_dialog(lua_State *L)
 	lua_pushcfunction(L,gsdl_done);
 	lua_rawset(L,-3);
 
-	luaL_openlib(L, NULL, &gsdl_funcs[1], 0);
-	luaL_openlib(L, LUA_MODULE_NAME, gsdl_funcs, 0);
+	luaL_register(L, NULL, &gsdl_funcs[1]);
+	luaL_register(L, LUA_MODULE_NAME, gsdl_funcs);
 	return 0;
 }
 
